Task: NarrativeQA
==================
Description: A dataset and set of tasks in which the reader must answer questions about stories by reading entire books or movie scripts. From Kočiský et. al. '17. 

Link: https://arxiv.org/abs/1712.07040'

Tags: #NarrativeQA, #All, #QA

Notes: You can access summaries only task for NarrativeQA by using task 'narrative_qa:summaries'. By default, only stories are provided.

